==> aTunes_1.10.1.tar.gz: aTunes/src/net/sourceforge/atunes/kernel/modules/contextInformation/lastfm/runnables/LastFmCoversRunnable.java <==
/*
 * aTunes 1.10.1
 * Copyright (C) 2006-2008 Alex Aranda, Sylvain Gaudard, Thomas Beckers and contributors
 *
 * See http://www.atunes.org/wiki/index.php?title=Contributing for information about contributors
 *
 * http://www.atunes.org
 * http://sourceforge.net/projects/atunes
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 */

package net.sourceforge.atunes.kernel.modules.contextInformation.lastfm.runnables;

import java.awt.Image;
import java.util.List;

import javax.swing.SwingUtilities;

import net.sourceforge.atunes.kernel.modules.contextInformation.AlbumInfo;
import net.sourceforge.atunes.kernel.modules.contextInformation.ContextInformationListener;
import net.sourceforge.atunes.kernel.modules.contextInformation.lastfm.LastFmService;
import net.sourceforge.atunes.kernel.modules.repository.audio.AudioFile;
import net.sourceforge.atunes.model.AudioObject;

/**
 * The Class LastFmCoversRunnable.
 */
public class LastFmCoversRunnable implements Runnable {

	/** The listener. */
	ContextInformationListener listener;

	/** The service. */
	private LastFmService service;

	/** The albums. */
	private List<? extends AlbumInfo> albums;

	/** The interrupted. */
	private volatile boolean interrupted;

	/** The id. */
	long id;

	/** The audio file */
	AudioObject audioObject;

	/**
	 * Instantiates a new audio scrobbler covers runnable.
	 * 
	 * @param listener
	 *            the listener
	 * @param service
	 *            the service
	 * @param albums
	 *            the albums
	 * @param id
	 *            the id
	 */
	public LastFmCoversRunnable(ContextInformationListener listener, LastFmService service, List<? extends AlbumInfo> albums, long id, AudioObject audioObject) {
		this.listener = listener;
		this.service = service;
		this.albums = albums;
		this.id = id;
		this.audioObject = audioObject;
	}

	/**
	 * Interrupt.
	 */
	public void interrupt() {
		interrupted = true;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see java.lang.Runnable#run()
	 */
	@Override
	public void run() {
		if (albums != null) {
			SwingUtilities.invokeLater(new Runnable() {
				@Override
				public void run() {
					listener.notifyStartRetrievingCovers(id);
				}
			});
			for (int i = 0; i < albums.size(); i++) {
				final Image img;
				final AlbumInfo album = albums.get(i);
				if (!interrupted && audioObject instanceof AudioFile) {
					img = service.getImage(album, (AudioFile) audioObject);
				} else {
					img = null;
				}

				if (!interrupted) {
					SwingUtilities.invokeLater(new Runnable() {
						@Override
						public void run() {
							listener.notifyCoverRetrieved(album, img, id);
						}
					});
				}
			}
		}
	}
}

==> aTunes_1.11.0.tar.gz: aTunes/src/net/sourceforge/atunes/kernel/modules/contextInformation/lastfm/runnables/LastFmCoversRunnable.java <==
/*
 * aTunes 1.11.0
 * Copyright (C) 2006-2008 Alex Aranda, Sylvain Gaudard, Thomas Beckers and contributors
 *
 * See http://www.atunes.org/wiki/index.php?title=Contributing for information about contributors
 *
 * http://www.atunes.org
 * http://sourceforge.net/projects/atunes
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 */

package net.sourceforge.atunes.kernel.modules.contextInformation.lastfm.runnables;

import java.awt.Image;
import java.util.List;

import javax.swing.SwingUtilities;

import net.sourceforge.atunes.kernel.modules.contextInformation.AlbumInfo;
import net.sourceforge.atunes.kernel.modules.contextInformation.ContextInformationListener;
import net.sourceforge.atunes.kernel.modules.contextInformation.lastfm.LastFmService;
import net.sourceforge.atunes.kernel.modules.repository.audio.AudioFile;
import net.sourceforge.atunes.model.AudioObject;

/**
 * The Class LastFmCoversRunnable.
 */
public class LastFmCoversRunnable implements Runnable {

	/** The listener. */
	ContextInformationListener listener;

	/** The service. */
	private LastFmService service;

	/** The albums. */
	private List<? extends AlbumInfo> albums;

	/** The interrupted. */
	private volatile boolean interrupted;

	/** The id. */
	long id;

	/** The audio file */
	AudioObject audioObject;

	/**
	 * Instantiates a new audio scrobbler covers runnable.
	 * 
	 * @param listener
	 *            the listener
	 * @param service
	 *            the service
	 * @param albums
	 *            the albums
	 * @param id
	 *            the id
	 */
	public LastFmCoversRunnable(ContextInformationListener listener, LastFmService service, List<? extends AlbumInfo> albums, long id, AudioObject audioObject) {
		this.listener = listener;
		this.service = service;
		this.albums = albums;
		this.id = id;
		this.audioObject = audioObject;
	}

	/**
	 * Interrupt.
	 */
	public void interrupt() {
		interrupted = true;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see java.lang.Runnable#run()
	 */
	@Override
	public void run() {
		if (albums != null) {
			SwingUtilities.invokeLater(new Runnable() {
				@Override
				public void run() {
					listener.notifyStartRetrievingCovers(id);
				}
			});
			for (int i = 0; i < albums.size(); i++) {
				final Image img;
				final AlbumInfo album = albums.get(i);
				if (!interrupted && audioObject instanceof AudioFile) {
					img = service.getImage(album);
				} else {
					img = null;
				}

				if (!interrupted) {
					SwingUtilities.invokeLater(new Runnable() {
						@Override
						public void run() {
							listener.notifyCoverRetrieved(album, img, id);
						}
					});
				}
			}
		}
	}
}
